@@ -39,15 +39,21 @@ class DashboardExtension(LavaServerExtension):
     def front_page_template(self):
         return "dashboard_app/front_page_snippet.html"
 
+    def get_front_page_context(self):
+        from dashboard_app.models import DataReport
+        return {
+            'report_list': DataReport.repository.filter(front_page=True)
+        }
+
     @property
     def description(self):
         return "Validation Dashboard"
 
     @property
     def version(self):
-        from dashboard_app import __version__
+        import dashboard_app 
         import versiontools
-        return versiontools.format_version(__version__)
+        return versiontools.format_version(dashboard_app.__version__, hint=dashboard_app)
 
     @property
     def api_class(self):
@@ -56,10 +62,7 @@ class DashboardExtension(LavaServerExtension):
 
     def contribute_to_settings(self, settings_module):
         super(DashboardExtension, self).contribute_to_settings(settings_module)
-        settings_module['INSTALLED_APPS'].extend([
-            "linaro_django_pagination",
-            "south",
-        ])
+        settings_module['INSTALLED_APPS'].append("linaro_django_pagination")
         settings_module['MIDDLEWARE_CLASSES'].append(
             'linaro_django_pagination.middleware.PaginationMiddleware')
         root_dir = os.path.normpath(os.path.join(os.path.dirname(__file__), ".."))
